@@ -2,8 +2,8 @@
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: asn1-types
 version: 0.3.2
-id: asn1-types-0.3.2-373d90c7a1b36e8b9d0fe76023835d30
-key: asn1t_6uyF88PICD359B0mWeP6nA
+id: asn1-types-0.3.2-3969820adc8283f126affe054010f830
+key: asn1t_BR43uodYA6j1oMVNuWbt5p
 license: BSD3
 copyright: Vincent Hanquez <vincent@snarc.org>
 maintainer: Vincent Hanquez <vincent@snarc.org>
@@ -22,11 +22,11 @@ trusted: False
 import-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-types-0.3.2
 library-dirs: /usr/lib/ghc-7.10.3/site-local/asn1-types-0.3.2
 data-dir: /usr/share/arm-linux-ghc-7.10.3/asn1-types-0.3.2
-hs-libraries: HSasn1-types-0.3.2-6uyF88PICD359B0mWeP6nA
+hs-libraries: HSasn1-types-0.3.2-BR43uodYA6j1oMVNuWbt5p
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    hourglass-0.2.9-d44f07201da9fd2656b62ae800dd5aa9
+    hourglass-0.2.10-b11bcf654d7049575fb45d24076b832b
     memory-0.11-3a745e41fe78387f608c420e9b455d25
 haddock-interfaces: /usr/share/doc/haskell-asn1-types/html/asn1-types.haddock
 haddock-html: /usr/share/doc/haskell-asn1-types/html
